ADXL343
=========================================


.. automodule:: micropython_adxl343
    :members:

.. automodule:: micropython_adxl343.adxl343
    :members:

.. automodule:: micropython_adxl343.i2c_helpers
    :members:
